@@ -1,11 +1,23 @@
+/*
+htop - AffinityPanel.c
+(C) 2004-2011 Hisham H. Muhammad
+Released under the GNU GPL, see the COPYING file
+in the source distribution for its full text.
+*/
 
-#include "ProcessList.h"
 #include "AffinityPanel.h"
-#include "Panel.h"
+
 #include "CheckItem.h"
 
-#include "debug.h"
 #include <assert.h>
+#include <string.h>
+
+/*{
+#include "Panel.h"
+#include "Affinity.h"
+#include "ProcessList.h"
+#include "ListItem.h"
+}*/
 
 static HandlerResult AffinityPanel_eventHandler(Panel* this, int ch) {
    CheckItem* selected = (CheckItem*) Panel_getSelected(this);
@@ -38,7 +50,7 @@ Panel* AffinityPanel_new(ProcessList* pl, Affinity* affinity) {
       } else {
          mode = false;
       }
-      Panel_add(this, (Object*) CheckItem_new(String_copy(number), NULL, mode));         
+      Panel_add(this, (Object*) CheckItem_new(strdup(number), NULL, mode));         
    }
    return this;
 }
