@@ -1,22 +1,21 @@
 /*
 htop - CRT.c
-(C) 2004-2010 Hisham H. Muhammad
+(C) 2004-2011 Hisham H. Muhammad
 Released under the GNU GPL, see the COPYING file
 in the source distribution for its full text.
 */
 
 #include "CRT.h"
 
+#include "config.h"
+#include "String.h"
+
 #include <curses.h>
 #include <signal.h>
 #include <stdlib.h>
-#include <stdbool.h>
+#ifdef HAVE_EXECINFO_H
 #include <execinfo.h>
-
-#include "String.h"
-
-#include "config.h"
-#include "debug.h"
+#endif
 
 #define ColorPair(i,j) COLOR_PAIR((7-i)*8+j)
 
@@ -38,9 +37,8 @@ in the source distribution for its full text.
 
 //#link curses
 
-bool CRT_hasColors;
-
 /*{
+#include <stdbool.h>
 
 typedef enum ColorElements_ {
    RESET_COLOR,
@@ -110,12 +108,16 @@ typedef enum ColorElements_ {
 
 // TODO: centralize these in Settings.
 
+static bool CRT_hasColors;
+
 int CRT_delay = 0;
 
 int CRT_colorScheme = 0;
 
 int CRT_colors[LAST_COLORELEMENT] = { 0 };
 
+int CRT_cursorX = 0;
+
 char* CRT_termType;
 
 void *backtraceArray[128];
@@ -125,12 +127,14 @@ static void CRT_handleSIGSEGV(int sgn) {
    CRT_done();
    #if __linux
    fprintf(stderr, "\n\nhtop " VERSION " aborting. Please report bug at http://htop.sf.net\n");
+   #ifdef HAVE_EXECINFO_H
+   size_t size = backtrace(backtraceArray, sizeof(backtraceArray) / sizeof(void *));
+   fprintf(stderr, "Backtrace: \n");
+   backtrace_symbols_fd(backtraceArray, size, 2);
+   #endif
    #else
    fprintf(stderr, "\n\nhtop " VERSION " aborting. Unsupported platform.\n");
    #endif
-   size_t size = backtrace(backtraceArray, sizeof(backtraceArray));
-   fprintf(stderr, "Backtrace: \n");
-   backtrace_symbols_fd(backtraceArray, size, 2);
    abort();
 }
 
